/////////////////////////////////////////////////////////////////////////////////
// dialogs.gs
// included by game.gs
// Deals with common dialogs and messages boxes
/////////////////////////////////////////////////////////////////////////////////

/////////////////////////////////////////////////////////////////////////////////
// Those are used for compatibility with v1.1 and are refering to the top dialog
/////////////////////////////////////////////////////////////////////////////////

func DialogPush() 				{ DlgPush(); }
func DialogPop()				{ DlgPop(); }
func DialogPopAll()				{ DlgPopAll(); }
func DialogCount()				{ DlgCount(); }
func DialogSetPos( x, y )		{ idx=DlgCount()-1; DlgSet(idx,DLG_X,x); DlgSet(idx,DLG_Y,y); }
func DialogSetSize( w, h )		{ idx=DlgCount()-1; DlgSet(idx,DLG_W,w); DlgSet(idx,DLG_H,h); }
func DialogSetColor( color )	{ idx=DlgCount()-1; DlgSet(idx,DLG_COLOR,color); }
func DialogSetText( text )		{ idx=DlgCount()-1; DlgSetText(idx,text); }
func DialogTextW()				{ idx=DlgCount()-1; return HudGetTextWidth(DlgGetText(idx)); }
func DialogTextH()				{ idx=DlgCount()-1; return HudGetTextHeight(DlgGetText(idx)); }

/////////////////////////////////////////////////////////////////////////////////
// IN: int(dialog index)
// Draw a dialog with border and text
// Should be called only from the draw handler
// Do NOT abuse it !
/////////////////////////////////////////////////////////////////////////////////
func DialogDraw( idx )
{
	x = DlgGet(idx,DLG_X)+8;
	y = DlgGet(idx,DLG_Y)+48;
	w = DlgGet(idx,DLG_W);
	h = DlgGet(idx,DLG_H);
	HudColor( DlgGet(idx,DLG_COLOR) );

	boxidx = TileFind(3);
	HudDrawTile( boxidx, x-16,y-16,16,16, 	0,0,16,16, 0, 0 );
	HudDrawTile( boxidx, x,y-16,w,16, 		16,0,8,16, 0, 0 );
	HudDrawTile( boxidx, x+w,y-16,16,16, 	24,0,16,16, 0, 0 );

	HudDrawTile( boxidx, x-16,y,16,h, 		0,16,16,8, 0, 0 );
	HudDrawTile( boxidx, x,y,w,h, 			16,16,8,8, 0, 0 );
	HudDrawTile( boxidx, x+w,y,16,h, 		24,16,16,8, 0, 0 );

	HudDrawTile( boxidx, x-16,y+h,16,16, 	0,24,16,40, 0, 0 );
	HudDrawTile( boxidx, x,y+h,w,16, 		16,24,8,40, 0, 0 );
	HudDrawTile( boxidx, x+w,y+h,16,16, 	24,24,16,40, 0, 0 );

	fontidx = TileFind(4);
	HudDrawText( fontidx, x, y+4, w, h, DlgGetText(idx), 0 );
}

/////////////////////////////////////////////////////////////////////////////////
// IN: int(x pixels), int(y pixels)
// Sets position of the last dialog.
// Auto sets the size as required by text.
// If possible it prevents the dialog from crossing screen's borders.
/////////////////////////////////////////////////////////////////////////////////
func DialogFitAt(x,y)
{
	border = 16;
	w = DialogTextW()*8+8; // add some space
	h = DialogTextH()*8+8; // add some space
	DialogSetSize(w,h);
	if(x+w+border>GAME_VIEWW) x=GAME_VIEWW-w-border;
	if(x<border) x=border;
	if(y+h+border>GAME_VIEWH) y=GAME_VIEWH-h-border;
	if(y<border) y=border;
	DialogSetPos(x,y);
}

/////////////////////////////////////////////////////////////////////////////////
// Auto sets position of the last dialog in the center of the screen.
// Auto sets the size as required by text.
/////////////////////////////////////////////////////////////////////////////////
func DialogFitCenter()
{
	border = 16;
	w = DialogTextW()*8+8; // add some space
	h = DialogTextH()*8+8; // add some space
	DialogSetSize(w,h);
	x = (GAME_VIEWW-w-border)/2;
	y = (GAME_VIEWH-h-border)/2;
	DialogSetPos(x,y);
}

/////////////////////////////////////////////////////////////////////////////////
// Runs a dialog, waiting until a key (MENU or ACTION) is pressed.
/////////////////////////////////////////////////////////////////////////////////
func DialogRun()
{
	while(true)
	{
		stop;
		if( GetKeyHit(KEY_MENU) || GetKeyHit(KEY_ACTION) ) break;
	}
	ClearKeys();
}

/////////////////////////////////////////////////////////////////////////////////
// IN: int(fid_dialog)
// IN: int(selections count)
// IN: [int(default selection=0])
// IN: [int(norefuse=0)]
// OUT: int(selection index/-1)
// Runs a multi-selection dialog.
// Uses LEFT and RIGHT keys to navigate and ACTION key to select.
// If norefuse, you can't press MENU key to close without selecting something.
// The dialog creation function (fid_dialog) receives the selection index as a parameter.
/////////////////////////////////////////////////////////////////////////////////
func RunDialogSelect( fid_dialog, count, default, norefuse )
{
	if(fid_dialog==-1) return;
	if(!?default) default = 0;
	if(!?norefuse) norefuse = false;

	select = default;
	while(true)
	{
		call( select, fid_dialog );
		refresh = false;
		while(!refresh)
		{
			stop;
			if(GetKeyHit(KEY_LEFT) && select>0) { select--; refresh=true; }
			else
			if(GetKeyHit(KEY_RIGHT) && select<count-1) { select++; refresh=true; }
			else
			if(GetKeyHit(KEY_ACTION))
			{
				DialogPop();
				ClearKeys();
				return select;
			}
			if(GetKeyHit(KEY_MENU) && !norefuse)
			{
				DialogPop();
				ClearKeys();
				return -1;
			}
		}
		DialogPop();
	}
}

/////////////////////////////////////////////////////////////////////////////////
// IN: str(text) [,int(border color/COLOR_DIALOG)]
// Opens a simple message dialog and runs it.
/////////////////////////////////////////////////////////////////////////////////
func OpenDialogMessage( text, color )
{
	if(!?color) color = COLOR_DIALOG;
	GamePause(1);
	DialogPush();
	DialogSetText(text);
	DialogSetColor(color);
	DialogFitCenter();
	DialogRun();
	DialogPop();
	GamePause(0);
}

str g_dlgquestion_text;
/////////////////////////////////////////////////////////////////////////////////
// IN: str(text) [,int(0=yes default, 1=no default)]
// OUT: int(choice 0=yes, 1=no)
// Opens a question yes/no dialog.
// Uses DialogQuestion function for dialog creation.
/////////////////////////////////////////////////////////////////////////////////
func OpenDialogQuestion( text, default )
{
	if(!?default) default=0;
	color = COLOR_DIALOG;
	g_dlgquestion_text = text;
	select = RunDialogSelect( gs_fid("DialogQuestion"), 2, default, true );
	return (select==0);
}

// IN: int(default selection 0/1)
// Dialog creation function used by OpenDialogQuestion
func DialogQuestion( select )
{
	text = "{a:center}"+g_dlgquestion_text+"\n\n{c:0xff0000}";
	if(select==0) 	text += "{f:1}YES{f:0}   NO";
	else			text += "YES   {f:1}NO{f:0}";
	DialogPush();
	DialogSetText(text);
	DialogSetColor(COLOR_DIALOG);
	DialogFitCenter();
}

/////////////////////////////////////////////////////////////////////////////////
// Opens the Menu dialog.
// Uses DialogPause function for dialog creation.
/////////////////////////////////////////////////////////////////////////////////
func OpenDialogPause()
{
	GamePause(1);
	select = RunDialogSelect( gs_fid("DialogPause"), 5, 0 );
	if(select==1)
	{
		OpenDialogFiles(1);
	}
	else
	if(select==2)
	{
		OpenDialogFiles(0);
	}
	else
	if(select==3)
	{
		if(OpenDialogQuestion("RESTART GAME ?",1))
			 GameCommand(CMD_START);
	}
	else
	if(select==4)
	{
		if(OpenDialogQuestion("EXIT GAME ?",1))
			GameCommand(CMD_EXIT);
	}
	GamePause(0);
}

// IN: int(default selection)
// Dialog creation function used by OpenDialogPause.
func DialogPause( select )
{
	text = "{a:center}GAME PAUSED\n\n{c:0xff0000}";
	if(select==0) text += "{f:1}RESUME{f:0}\n"; 	else text += "RESUME\n";
	if(select==1) text += "{f:1}SAVE{f:0}\n"; 		else text += "SAVE\n";
	if(select==2) text += "{f:1}LOAD{f:0}\n"; 		else text += "LOAD\n";
	if(select==3) text += "{f:1}RESTART{f:0}\n"; 	else text += "RESTART\n";
	if(select==4) text += "{f:1}EXIT{f:0}"; 		else text += "EXIT";
	DialogPush();
	DialogSetText(text);
	DialogSetColor(COLOR_DIALOG);
	DialogFitCenter();
}

/////////////////////////////////////////////////////////////////////////////////
// IN: [int(select_exit=0)]
// OUT: int(object's index, or -1=exit without selecting)
// Opens the Inventory dialog.
// Internally, the selection goes from [0 to InventoryCount()] (last selection means return without dropping).
// If select_exit is 0, the top item is selected, else theexit option.
// Uses DialogInventory function for dialog creation.
/////////////////////////////////////////////////////////////////////////////////
func OpenDialogInventory( defaultexit )
{
	if(!?defaultexit) defaultexit=0;
	GamePause(1);
	count = InventoryCount();
	default = 0;
	if(defaultexit) default = count;
	select = RunDialogSelect( gs_fid("DialogInventory"), count+1, default );
	// WaitFrames(4);
	GamePause(0);
	if( select==count || select==-1 ) return -1; // no selection
	idx = InventoryGet(count-1-select); // item selected
	return idx;
}

// IN: int(default selection)
// Dialog creation function used by OpenDialogInventory.
func DialogInventory( select )
{
	// construct text
	text = "{a:center}YOU ARE CARRYING\n\n{c:0xff0000}";

	// push elements names in reverse order (last is first)
	count = InventoryCount();
	if(count>0)
	{
		for(i=count-1;i>=0;i--)
		{
			idx = InventoryGet(i);
			if(select==count-1-i) text += "{f:1}";
			text += ObjGetName(idx);
			if(select==count-1-i) text += "{f:0}";
			text += "\n";
		}
		height = 5+count;
	}
	else
	{
		text += "{c:0xffffffff}NOTHING\n";
		height = 5+1;
	}

	if(select==count) text += "{f:1}";
	text += "\nExit and don't drop";
	if(select==count) text += "{f:0}";

	// construct dialog
	DialogPush();
	DialogSetText(text);
	DialogSetColor(COLOR_DIALOG);
	DialogFitCenter();
}

str g_dialogfiles_title;
/////////////////////////////////////////////////////////////////////////////////
// IN: int(mode: 0=load, 1=save)
// Opens the game files dialog.
// Uses DialogFiles function for dialog creation.
/////////////////////////////////////////////////////////////////////////////////
func OpenDialogFiles( mode )
{
	g_dialogfiles_title = (mode==0) ? "LOAD GAME" : "SAVE GAME";
	select = RunDialogSelect( gs_fid("DialogFiles"), 4, 0 );
	if(select==3 || select==-1) return; // give up
	file = "save"+(str)(select+1)+".gam";
	info = gs_fileinfo(file);
	if(mode==0)
	{
		if(strempty(info))
		{
			OpenDialogMessage( "SLOT IS EMPTY", 0xffff0000 );
			return;
		}
		LoadGame(file);
	}
	else
	{
		//if(!strempty(info))
		//{
		//	if(!OpenDialogQuestion("OVERWRITE FILE ?",1)) return;
		//}
		SaveGame(file);
	}
}

// IN: int(default selection)
// Dialog creation function used by OpenDialogFiles.
func DialogFiles( select )
{
	text = "{a:center}"+g_dialogfiles_title+"\n\n{c:0xff0000}";
	for(i=0;i<3;i++)
	{
		if(select==i) text+="{f:1}";
		file = "save"+(str)(i+1)+".gam";
		info = gs_fileinfo(file);
		if(strempty(info))
		{
			text+=" EMPTY  ";
			text+="SLOT        ";
		}
		else
		{
			text+=" FILE"+(str)(i+1)+"  ";
			text+=strupr(strsub(info,4,12));
		}
		if(select==i) text+="{f:0}";
		text += " \n";
	}
	text += "\n";
	if(select==3) text += "{f:1}RETURN{f:0}"; else text += "RETURN";
	DialogPush();
	DialogSetText(text);
	DialogSetColor(COLOR_DIALOG);
	DialogFitCenter();
}

/////////////////////////////////////////////////////////////////////////////////
// Opens the Finish dialog
// Uses DialogFinish function for dialog creation.
/////////////////////////////////////////////////////////////////////////////////
func OpenDialogFinish()
{
	GamePause(1);
	select = RunDialogSelect( gs_fid("DialogFinish"), 3, 0, 1 );
	if(select==0)
	{
		gs_shell("http://www.simion.co.uk/dizzyage");
		GameCommand(CMD_START);
	}
	if(select==1)
	{
		GameCommand(CMD_START);
	}
	else
	if(select==2)
	{
		GameCommand(CMD_EXIT);
	}
	GamePause(0);
}

// IN: int(default selection)
// Dialog creation function used by OpenDialogFinish.
func DialogFinish( select )
{
	text = "{a:center}GAME PAUSED\n\n{c:0xff0000}";
	if(select==0) text += "{f:1}WEB SITE{f:0}\n";	else text += "WEB SITE\n";
	if(select==1) text += "{f:1}RESTART{f:0}\n"; 	else text += "RESTART\n";
	if(select==2) text += "{f:1}EXIT{f:0}"; 		else text += "EXIT";
	DialogPush();
	DialogSetText(text);
	DialogSetColor(COLOR_DIALOG);
	DialogFitCenter();
}


/////////////////////////////////////////////////////////////////////////////////
// Messages
/////////////////////////////////////////////////////////////////////////////////
int g_msglastx; 	// position x of the last message
int g_msglasty; 	// position y of the last message
int g_msglastink; 	// ink color of the last message
int g_msglastborder;// border color of the last message

/////////////////////////////////////////////////////////////////////////////////
// IN: int(x), int(y), str(text),
// IN: int(text color), int(border color)
// position is given in characters : x=[0,30), y=[0,17)
// Stores x, y, and colors, for use with MessageNext.
// This does not closes the dialog. Needs DialogPop().
/////////////////////////////////////////////////////////////////////////////////
func Message( x, y, text, colorink, colorborder )
{
	g_msglastx = x;
	g_msglasty = y;
	g_msglastink = colorink;
	g_msglastborder = colorborder;

	x*=8; y*=8;
	GamePause(1);
	DialogPush();
	DialogSetText("{c:0x"+(str "%x")colorink+"}"+text);
	DialogSetColor(colorborder);
	DialogFitAt(x,y);
	DialogRun();
	GamePause(0);
}

/////////////////////////////////////////////////////////////////////////////////
// IN: str(text) [,int(stepx/1) [,int(stepy/1)]]
// Opens another dialog message in cascade, using position and colors of the last message.
// This does not closes the dialog. Needs DialogPop() or DialogPopAll().
/////////////////////////////////////////////////////////////////////////////////
func MessageNext( text, stepx, stepy )
{
	if(!?stepx) stepx = 1;
	if(!?stepy) stepy = 1;
	Message( g_msglastx+stepx, g_msglasty+stepy, text, g_msglastink, g_msglastborder );
}

/////////////////////////////////////////////////////////////////////////////////
// Closes all opened messages using DialogPopAll().
/////////////////////////////////////////////////////////////////////////////////
func MessagePop()
{
	DialogPopAll();
}

// IN: int(x), int(y)), str(text)
// quick call for Message: story teller settings
func Message0( x, y, text )
{
	Message( x, y, text, COLOR_WHITE, COLOR_RED );
}

// IN: int(x), int(y), str(text)
// quick call for Message: dizzy settings
func Message1( x, y, text )
{
	Message( x, y, text, COLOR_MAGENTA, COLOR_GREEN );
}

// IN: int(x), int(y), str(text),
// IN: [,int(text color=COLOR_WHITE)]
// quick call for Message: other characters' settings
func Message2( x, y, text, color )
{
	if(!?color) color = COLOR_WHITE;
	Message( x, y, text, color, COLOR_GREEN );
}

/////////////////////////////////////////////////////////////////////////////////
