/////////////////////////////////////////////////////////////////////////////////
// file.gs
// Save and load game operations.
/////////////////////////////////////////////////////////////////////////////////

// IN: int(file), int(brush id)
// Loads a brush from a file.
func LoadBrush( file, id )
{
	val=0;
	b = BrushFind(id); 
	if(b==-1) return 0;
	for(i=0;i<B_MAX;i++)
	{
		if(!gs_filereadint(&val, file)) return 0;
		BrushSet(b,i,val);
	}
	return 1;
}

// IN: int(file), int(brush id)
// Saves a brush into a file.
func SaveBrush( file, id )
{
	val=0;
	b = BrushFind(id); 
	if(b==-1) return 0;
	for(i=0;i<B_MAX;i++)
	{
		if(!gs_filewriteint(BrushGet(b,i), file)) return 0;
	}
	return 1;	
}

// IN: str(file name)
// Loads a game and display the result message.
func LoadGame( file )
{
	f = gs_fileopen(file,0); if(!f) goto fileerrorrecover;

	val=0;
	sz="";
	
	// load id
	if(!gs_filereadtext(&sz,f)) goto fileerrorrecover;
	if(sz!="DIZZYAGE") goto fileerrorrecover;
	
	// load game data
	for(i=0;i<G_MAX;i++)
	{
		if(!gs_filereadint(&val, f)) goto fileerror;
		GameSet(i,val);
	}

	// load ojects data
	for(o=0;o<ObjCount();o++)
	{
		for(i=0;i<O_MAX;i++)
		{
			if(!gs_filereadint(&val, f)) goto fileerror;
			ObjSet(o,i,val);
		}
	}

	// load player data
	for(i=0;i<P_MAX;i++)
	{
		if(!gs_filereadint(&val, f)) goto fileerror;
		PlayerSet(i,val);
	}

	// additional user data 
	// manually load all brushes that you may change during gameplay
//	savebrushes = {1016,1017,1020 }; // edit this list with brushes ids
//	for(i=0;i<sizeof(savebrushes);i++)
//		if(!LoadBrush(f,savebrushes[i])) goto fileerror;

	gs_fileclose(f);
	
	// reload room
	MusicPlay(GetLocationMusic(),0,3);
	GameCommand(CMD_REFRESH);
	ObjPresentGather(); // refresh present list	
	SamplePlay(FX_RESPAWN);
	OpenDialogMessage( "LOAD SUCCESSFUL!", COLOR_YELLOW );
	return;
	
fileerror:
	OpenDialogMessage( "FILE ERROR!", COLOR_RED ); 
	gs_fileclose(f);
	GameCommand(CMD_EXIT);
	return;
	
fileerrorrecover:
	OpenDialogMessage( "FILE ERROR!", COLOR_RED ); 
	gs_fileclose(f);
	return;		
}

// IN: str(file name)
// Saves a game and display the result message.
func SaveGame( file )
{
	f = gs_fileopen(file,1); if(!f) goto fileerror;
	
	// save id
	if(!gs_filewritetext( "DIZZYAGE", f )) goto fileerror;
	
	// save game data
	for(i=0;i<G_MAX;i++)
	{
		if(!gs_filewriteint(GameGet(i), f)) goto fileerror;
	}
	
	// save ojects data
	for(o=0;o<ObjCount();o++)
	{
		for(i=0;i<O_MAX;i++)
		{
			if(!gs_filewriteint(ObjGet(o,i), f)) goto fileerror;
		}
	}
	
	// save player data
	for(i=0;i<P_MAX;i++)
	{
		if(!gs_filewriteint(PlayerGet(i), f)) goto fileerror;
	}

	// additional user data
	// manually save all brushes that you may change during gameplay
//	savebrushes = {1016,1017,1020 }; // edit this list with brush ids
//	for(i=0;i<sizeof(savebrushes);i++)
//		if(!SaveBrush(f,savebrushes[i])) goto fileerror;

	gs_fileclose(f);
	
	SamplePlay(FX_COIN);
	OpenDialogMessage( "SAVE SUCCESSFUL!", COLOR_YELLOW ); 
	return;
	
fileerror:
	OpenDialogMessage( "FILE ERROR!", COLOR_RED );
	gs_fileclose(f);
	return;			
}

/////////////////////////////////////////////////////////////////////////////////
