/////////////////////////////////////////////////////////////////////////////////
// Inventory
// Items are stored as object indexes in game variables starting with G_INVENTORY
// Items are stored consecutive, followed by a -1 value
// -1 value in inventory means no item
// There could be a maximum of G_USER-G_INVENTORY items in the inventory (<=14)
// MAXINVENTORY is defined to limit the number of items the player can carry
/////////////////////////////////////////////////////////////////////////////////


/////////////////////////////////////////////////////////////////////////////////
// OUT: int(items count)
// Counts current items in the inventory.
/////////////////////////////////////////////////////////////////////////////////
func InventoryCount()
{
	for(i=0;i<MAXINVENTORY;i++)
		if(GameGet(G_INVENTORY+i)==-1)
			break;
	return i;
}

/////////////////////////////////////////////////////////////////////////////////
// IN: int(object index)
// OUT: int(0=no slots available, 1=success)
// Adds an item to the inventory.
/////////////////////////////////////////////////////////////////////////////////
func InventoryAdd( idx )
{
	count = InventoryCount();
	if(count==MAXINVENTORY) return 0; // inventory is full
	GameSet(G_INVENTORY+count,idx);
	return 1;
}

/////////////////////////////////////////////////////////////////////////////////
// IN: int(object index)
// OUT: int(0=not found, 1=success)
// Substracts an item from the inventory.
/////////////////////////////////////////////////////////////////////////////////
func InventorySub( idx )
{
	count = InventoryCount();
	// find item slot
	for(i=0;i<count;i++)
		if(GameGet(G_INVENTORY+i)==idx)
			break;

	if(i==count) return 0; // item not found

	// shift remaining elements over the found one
	while(i<count-1)
	{
		idx = GameGet(G_INVENTORY+i+1);
		GameSet(G_INVENTORY+i,idx);
		i++;
	}
		
	// clear last
	GameSet(G_INVENTORY+count-1,-1);
		
	return 1;
}

/////////////////////////////////////////////////////////////////////////////////
// Removes all items from the inventory.
/////////////////////////////////////////////////////////////////////////////////
func InventoryClear()
{
	for(i=0;i<MAXINVENTORY;i++)
		GameSet(G_INVENTORY+i,-1);
}

/////////////////////////////////////////////////////////////////////////////////
// IN: int(object index)
// OUT: int(inventory slot/-1)
// Returns the coresponding inventory position for an item.
/////////////////////////////////////////////////////////////////////////////////
func InventoryFind( idx )
{
	count = InventoryCount();
	for(i=0;i<count;i++)
		if( GameGet(G_INVENTORY+i)==idx )
			return i;
	return -1;
}

/////////////////////////////////////////////////////////////////////////////////
// IN: int(inventory slot)
// OUT: int(object index/-1)
// Return an item index from an inventory slot.
/////////////////////////////////////////////////////////////////////////////////
func InventoryGet( slot )
{
	if(slot<0 || slot>=MAXINVENTORY) return -1;
	return GameGet(G_INVENTORY+slot);
}

/////////////////////////////////////////////////////////////////////////////////
