/////////////////////////////////////////////////////////////////////////////////
// dialogs.gs
// included by game.gs
// Deals with sound and music loading
// OBS: do not exaggerate with too many musics
//		supported music files: YM, MOD, IT, XM, S3M (cached in memory), and WAV, OGG (streamed from hard drive)
// OBS: you can load as many samples as you like, but make sure they are not very big in size.
//		each sample is fully cached in memory
/////////////////////////////////////////////////////////////////////////////////

#def MUSIC_DEFAULT	0
#def MUSIC_TUNE1	1
#def MUSIC_TUNE2	2

#def FX_SUCCESS		0
#def FX_STUN		1
#def FX_DEATH		2
#def FX_RESPAWN		3
#def FX_COIN		4
#def FX_HURT		5
#def FX_JUMP		6
#def FX_BEEP1		7
#def FX_BEEP2		8

/////////////////////////////////////////////////////////////////////////////////
// Loads sounds and music (called by HandlerGameInit).
/////////////////////////////////////////////////////////////////////////////////
func SoundInit()
{
	MusicLoad( "Data\\Sounds\\music_tune0.ym" );
	MusicLoad( "Data\\Sounds\\music_tune1.ym" );
	MusicLoad( "Data\\Sounds\\music_tune2.ym" );

	SampleLoad( "Data\\Sounds\\fx_success.ym" );
	SampleLoad( "Data\\Sounds\\fx_stun.ogg" );
	SampleLoad( "Data\\Sounds\\fx_death.ym", 1 );
	SampleLoad( "Data\\Sounds\\fx_respawn.ym", 1 );
	SampleLoad( "Data\\Sounds\\fx_coin.ym", 1 );
	SampleLoad( "Data\\Sounds\\fx_hurt.ogg" );
	SampleLoad( "Data\\Sounds\\fx_jump.ogg", 1 );
	SampleLoad( "Data\\Sounds\\fx_beep1.ogg", 2 );
	SampleLoad( "Data\\Sounds\\fx_beep2.ogg", 2 );
}

/////////////////////////////////////////////////////////////////////////////////
// OUT: int(music idx)
// Returns a location specific music (usually the default game music).
// Called on start, respawn, load, triggers, etc.
/////////////////////////////////////////////////////////////////////////////////
func GetLocationMusic()
{
	return MUSIC_DEFAULT;
}

/////////////////////////////////////////////////////////////////////////////////
